@@ -646,15 +646,13 @@ impl BinaryReader for BytesReader {
                 self.ptr = pos as usize;
                 Ok(self.ptr as u64)
             },
-            SeekFrom::End(pos)=>{
-                if pos >= usize::MAX as i64 {
-                    let s = format!("BytesReader max offset is usize length but set {}",pos);
-                    return Err( Error::new(ErrorKind::Other, s))
-                } else if self.buffer.len() as i64 + pos < 0 || pos >= self.buffer.len() as i64 {
-                    let s = format!("set offset {},but buffer length is{}",pos,self.buffer.len());
+            SeekFrom::End(pos_)=>{
+                let pos = self.buffer.len() as i64 + pos_;
+                if pos < 0 || pos >= (self.buffer.len() as i64) {
+                    let s = format!("set offset {},but buffer length is {}",pos,self.buffer.len());
                     return Err( Error::new(ErrorKind::Other, s))
                 }
-                self.ptr = self.buffer.len() + pos as usize;
+                self.ptr = pos as usize;
                 Ok(self.ptr as u64)
             },
             SeekFrom::Current(pos)=>{
@@ -710,8 +708,8 @@ impl<R:BufRead+Seek> BinaryReader for StreamReader<R> {
     // However it's behavior dependences read buffer size.
     fn read_bytes_no_move(&mut self,len: usize) -> Result<Vec<u8>,Error> {
         let buffer = self.reader.fill_buf()?;
-        if buffer.len() <= len {
-            let err = "Data shotage";
+        if buffer.len() < len {
+            let err = format!("Data shotage,request {} but read {} bytes",len,buffer.len());
             return Err(Error::new(ErrorKind::Other,err));
         }
         let array: Vec<u8> = (0..len).map(|i| buffer[i]).collect();
