@@ -1,12 +1,10 @@
+use std::io::Cursor;
+use std::io::SeekFrom;
+use crate::reader::*;
+use crate::Endian;
 
-#[cfg(test)]
-mod tests {
-    use crate::reader::*;
-    use crate::Endian;
-    use std::error::Error;
-    #[test]
-
-    fn check_works() -> Result<(),std::io::Error> {
+#[test]
+    fn check_works() -> Result<(),Box<dyn std::error::Error>>{
         let buffer : Vec<u8> = (0..255).map(|i| i).collect();
         let mut reader = BytesReader::from_vec(buffer);
 
@@ -16,8 +14,10 @@ mod tests {
             } else {
                 Endian::LittleEndian
         };
+
+        let r = reader.endian();
         
-        assert_eq!(endian, reader.endian()?);
+        assert_eq!(endian, r);
     
 
         let r = reader.read_byte()?;
@@ -117,7 +117,7 @@ mod tests {
 
         let buffer = [0x71,0x3D,0x0A,0xD7,0xA3,0x30,0x31,0xC0];
         let mut reader = BytesReader::new(&buffer);
-        reader.set_endian(Endian::LittleEndtian);
+        reader.set_endian(Endian::LittleEndian);
         let r = reader.read_f64()?;
         assert_eq!(r ,-17.19);
 
@@ -126,18 +126,32 @@ mod tests {
         reader.set_endian(Endian::BigEndian);
         let r = reader.read_f64()?;
         assert_eq!(r ,-17.19);
+        
+        let buffer : Vec<u8> = (0..255).map(|i| i).collect();
+        let mut reader = BytesReader::new(&buffer);
+        reader.set_endian(Endian::BigEndian);
+        let r = reader.read_u16()?;
+        assert_eq!(r, 0x0001);
+        reader.set_endian(Endian::LittleEndian);
+        let r = reader.read_u16()?;
+        assert_eq!(r, 0x0302);
 
+        let r = reader.offset()?;
+        assert_eq!(r, 4);
+        let r = reader.seek(SeekFrom::End(-1))?;
+        assert_eq!(r, 254);
         Ok(())
     }
 
 
     #[cfg(feature="stream")]
     #[test]
-    fn check_stream () -> Result<(),std::io::Error> {
+    fn check_stream () -> Result<(),Box<dyn std::error::Error>> {
         use crate::reader::StreamReader;
 
         let buffer : Vec<u8> = (0..255).map(|i| i).collect();
-        let mut reader = StreamReader::new(&*buffer);
+        let f = Cursor::new(&*buffer);
+        let mut reader = StreamReader::new(f);
     
         let r = reader.read_byte()?;
         assert_eq!(r , 0_u8);
@@ -165,7 +179,9 @@ mod tests {
 
     
         let buffer : Vec<u8> = (0..32).map(|i| 255-i).collect();
-        let mut reader = StreamReader::new(&*buffer);
+        let f = Cursor::new(&*buffer);
+        let mut reader = StreamReader::new(f);
+
         let r = reader.read_i8()?;  // 0xff
         assert_eq!(r , -1);
         let r = reader.read_i16_be()?; // 0xfefd -> fefd
@@ -186,7 +202,9 @@ mod tests {
         }
     
         let buffer : Vec<u8> = (0..16).map(|i| 255-i).collect();
-        let mut reader = StreamReader::new(&*buffer);
+        let f = Cursor::new(&*buffer);
+        let mut reader = StreamReader::new(f);
+
         let r = reader.read_i64_be()?;
         assert_eq!(r , -283686952306184);
     
@@ -194,26 +212,36 @@ mod tests {
         assert_eq!(r , -1084818905618843913);
     
         let buffer = vec![0x41,0x89,0x85,0x1F];
-        let mut reader = StreamReader::new(&*buffer);
+        let f = Cursor::new(&*buffer);
+        let mut reader = StreamReader::new(f);
+
         let r = reader.read_f32_be()?;
         assert_eq!(r , 17.19);
     
         let buffer = vec![0x1F,0x85,0x89,0x41];
-        let mut reader = StreamReader::new(&*buffer);
+        let f = Cursor::new(&*buffer);
+        let mut reader = StreamReader::new(f);
+
         let r = reader.read_f32_le()?;
         assert_eq!(r , 17.19);
     
         let buffer = vec![0xC0,0x31,0x30,0xA3,0xD7,0x0A,0x3D,0x71];
-        let mut reader = StreamReader::new(&*buffer);
+        let f = Cursor::new(&*buffer);
+        let mut reader = StreamReader::new(f);
+
         let r = reader.read_f64_be()?;
         assert_eq!(r ,-17.19);
         let buffer = vec![0x71,0x3D,0x0A,0xD7,0xA3,0x30,0x31,0xC0];
-        let mut reader = StreamReader::new(&*buffer);
+        let f = Cursor::new(&*buffer);
+        let mut reader = StreamReader::new(f);
+
         let r = reader.read_f64_le()?;
         assert_eq!(r ,-17.19);
     
         let buffer = b"Hello World!".to_vec();
-        let mut reader = StreamReader::new(&*buffer);
+        let f = Cursor::new(&*buffer);
+        let mut reader = StreamReader::new(f);
+
         let buffer1 = reader.read_bytes_no_move(4)?;
         assert_eq!(buffer1,b"Hell");
         let buffer1 = reader.read_bytes_as_vec(4)?;
@@ -222,11 +250,15 @@ mod tests {
         assert_eq!(buffer1,b"o Wo");
     
         let buffer = b"Hello World!\01234".to_vec();
-        let mut reader = StreamReader::new(&*buffer);
+        let f = Cursor::new(&*buffer);
+        let mut reader = StreamReader::new(f);
+
         let r = reader.read_ascii_string("Hello World!\01234".len())?;  // must after \0 is trim
         assert_eq!(r ,"Hello World!");
         let buffer = b"\xE3\x81\xB8\xE3\x82\x8D\xE3\x83\xBC\xE3\x82\x8F\xE3\x83\xBC\xE3\x82\x8B\xE3\x81\xA9\01234".to_vec();
-        let mut reader = StreamReader::new(&*buffer);
+        let f = Cursor::new(&*buffer);
+        let mut reader = StreamReader::new(f);
+
         let r = reader.read_utf8_string(23)?;
         assert_eq!(r ,"へろーわーるど\01");
     
@@ -235,17 +267,37 @@ mod tests {
         }
     
         let buffer = [0x71,0x3D,0x0A,0xD7,0xA3,0x30,0x31,0xC0].to_vec();
-        let mut reader = StreamReader::new(&*buffer);
-        reader.set_endian(Endian::LittleEndtian);
+        let f = Cursor::new(&*buffer);
+        let mut reader = StreamReader::new(f);
+
+        reader.set_endian(Endian::LittleEndian);
         let r = reader.read_f64()?;
         assert_eq!(r ,-17.19);
     
         let buffer = [0xC0,0x31,0x30,0xA3,0xD7,0x0A,0x3D,0x71].to_vec();
-        let mut reader = StreamReader::new(&*buffer);
+        let f = Cursor::new(&*buffer);
+        let mut reader = StreamReader::new(f);
+
         reader.set_endian(Endian::BigEndian);
         let r = reader.read_f64()?;
         assert_eq!(r ,-17.19);
 
+        let buffer : Vec<u8> = (0..255).map(|i| i).collect();
+        let f = Cursor::new(&*buffer);
+        let mut reader = StreamReader::new(f);
+
+        reader.set_endian(Endian::BigEndian);
+        let r = reader.read_u16()?;
+        assert_eq!(r, 0x0001);
+        reader.set_endian(Endian::LittleEndian);
+        let r = reader.read_u16()?;
+        assert_eq!(r, 0x0302);
+
+        let r = reader.offset()?;
+        assert_eq!(r, 4);
+        let r = reader.seek(SeekFrom::End(-1))?;
+        assert_eq!(r, 254);
+
     
         Ok(())
         
@@ -253,7 +305,7 @@ mod tests {
 
     #[tokio::test]
     #[cfg(feature="async")]
-    pub async fn check_async () -> Result<(),Box<dyn Error>> {
+    pub async fn check_async () -> Result<(),Box<dyn std::error::Error>> {
         use crate::async_reader::AsyncBytesReader;
         let buffer : Vec<u8> = (0..255).map(|i| i).collect();
         let mut reader = AsyncBytesReader::new(&*buffer);
@@ -352,7 +404,7 @@ mod tests {
     
         let buffer = [0x71,0x3D,0x0A,0xD7,0xA3,0x30,0x31,0xC0].to_vec();
         let mut reader = AsyncBytesReader::new(&*buffer);
-        reader.set_endian(Endian::LittleEndtian);
+        reader.set_endian(Endian::LittleEndian);
         let r = reader.read_f64().await?;
         assert_eq!(r ,-17.19);
     
@@ -365,5 +417,3 @@ mod tests {
         Ok(())
         
     }
-    
-}
